@@ -15,7 +15,6 @@
 # limitations under the License.
 #
 
-import warnings
 from ai.h2o.sparkling.ExternalBackendConf import ExternalBackendConf
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.InternalBackendConf import InternalBackendConf
@@ -24,14 +23,10 @@ from pyspark.sql import SparkSession
 
 
 class H2OConf(SharedBackendConf, InternalBackendConf, ExternalBackendConf):
-    def __init__(self, spark=None):
+    def __init__(self):
         try:
-            if spark is not None:
-                warnings.warn(
-                    "Constructor H2OConf(spark) with spark argument is deprecated. Please use just H2OConf(). "
-                    "The argument will be removed in release 3.32.")
             Initializer.load_sparkling_jar()
             _jvm = SparkSession._instantiatedSession.sparkContext._jvm
-            self._jconf = _jvm.org.apache.spark.h2o.H2OConf()
+            self._jconf = _jvm.ai.h2o.sparkling.H2OConf()
         except:
             raise
