@@ -22,11 +22,10 @@ from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OTreeBasedSupervisedAlgorithm import H2OTreeBasedSupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OGBMMOJOModel import H2OGBMMOJOModel
 from ai.h2o.sparkling.ml.params.H2OGBMParams import H2OGBMParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.DistributionBasedH2OTrainFramePreparation import DistributionBasedH2OTrainFramePreparation
 
 
-class H2OGBM(H2OGBMParams, H2OCommonParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
+class H2OGBM(H2OGBMParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
@@ -34,7 +33,9 @@ class H2OGBM(H2OGBMParams, H2OCommonParams, H2OTreeBasedSupervisedAlgorithm, Dis
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
